==> nextcloud-app-mail-2.2.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_MX.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "Later" : "Después",
    "Mail" : "Correo",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connecting" : "Conectando",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Change name" : "Cambiar nombre",
    "Signature" : "Firma",
    "Cancel" : "Cancelar",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Select account" : "Selecciona la cuenta",
    "Subject" : "Asunto",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Sending …" : "Enviando ...",
    "Go back" : "Regresar",
    "Retry" : "Reintentar",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Unfavorite" : "Quitar favorito",
    "Favorite" : "Marcar como favorito",
    "Read" : "Leer",
    "Select" : "Seleccionar",
    "Edit tags" : "Editar etiquetas",
    "Move" : "Mover",
    "More actions" : "Más acciones",
    "Forward" : "Adelante",
    "All day" : "Todo el día",
    "Create" : "Crear",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Choose" : "Seleccionar",
    "Other" : "Otro",
    "Reply" : "Responder",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Remove account" : "Eliminar cuenta",
    "Mark all as read" : "Marcar todos como leídos",
    "Clear cache" : "Borrar el caché",
    "New message" : "Mensaje nuevo",
    "Message" : "Mensaje",
    "Delete" : "Borrar",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Agregar",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecciona las etiquetas",
    "Clear" : "Limpiar",
    "Search" : "Buscar",
    "Date" : "Fecha",
    "Disabled" : "Deshabilitado",
    "Enabled" : "Habilitado",
    "Custom" : "Personalizado",
    "Set" : "Establecer",
    "Unset" : "Desestablecer",
    "Add tag" : "Agregar etiqueta",
    "Tag already exists" : "La etiqueta ya existe",
    "Remove" : "Eliminar",
    "Reset" : "Reiniciar",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "General" : "General",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Keyboard shortcut" : "Atajo del teclado",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "All" : "Todos",
    "Archive" : "Archivar",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-mail-3.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_MX.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "Later" : "Después",
    "Mail" : "Correo",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connecting" : "Conectando",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Password required" : "Se requiere contraseña",
    "Signature" : "Firma",
    "Change name" : "Cambiar nombre",
    "Cancel" : "Cancelar",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Select account" : "Selecciona la cuenta",
    "Subject" : "Asunto",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Add link" : "Añadir liga",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Unfavorite" : "Quitar favorito",
    "Favorite" : "Marcar como favorito",
    "Read" : "Leer",
    "Select" : "Seleccionar",
    "Edit tags" : "Editar etiquetas",
    "More actions" : "Más acciones",
    "Forward" : "Adelante",
    "All day" : "Todo el día",
    "Create" : "Crear",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Choose" : "Seleccionar",
    "Other" : "Otro",
    "Reply" : "Responder",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Move" : "Mover",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Remove account" : "Eliminar cuenta",
    "Mark all as read" : "Marcar todos como leídos",
    "Edit name" : "Editar nombre",
    "Clear cache" : "Borrar el caché",
    "New message" : "Mensaje nuevo",
    "Go back" : "Regresar",
    "Retry" : "Reintentar",
    "Sending …" : "Enviando ...",
    "Message" : "Mensaje",
    "Delete" : "Borrar",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Agregar",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecciona las etiquetas",
    "Clear" : "Limpiar",
    "Search" : "Buscar",
    "Date" : "Fecha",
    "Disabled" : "Deshabilitado",
    "Enabled" : "Habilitado",
    "Custom" : "Personalizado",
    "Set" : "Establecer",
    "Unset" : "Desestablecer",
    "Add tag" : "Agregar etiqueta",
    "Tag already exists" : "La etiqueta ya existe",
    "Remove" : "Eliminar",
    "Reset" : "Reiniciar",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "General" : "General",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Valid until" : "Válido hasta",
    "Certificate" : "Certificado",
    "Back" : "Atrás",
    "Submit" : "Enviar",
    "Keyboard shortcut" : "Atajo del teclado",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Archive" : "Archivar",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
